#
# spec file for package log4cplus
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           log4cplus
Version:        1.1.0
Release:        lp151.2.3
%define soname  1_1-5
Summary:        C++ logging library
License:        Apache-2.0
Group:          Development/Libraries/C and C++
Url:            http://log4cplus.sourceforge.net/
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gcc-c++
BuildRequires:  pkg-config
BuildRequires:  xz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
log4cplus is a simple to use C++ logging API providing thread-safe,
flexible, and arbitrarily granular control over log management and
configuration. It is modeled after the Java log4j API.

%package -n lib%{name}-%{soname}
Summary:        C++ logging library
Group:          Development/Libraries/C and C++
Provides:       %{name} = %{version}

%description -n lib%{name}-%{soname}
log4cplus is a simple to use C++ logging API providing thread-safe,
flexible, and arbitrarily granular control over log management and
configuration. It is modeled after the Java log4j API.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       lib%{name}-%{soname} = %{version}

%description devel
This package provides development libraries and headers needed to
build software making use of %{name}

%prep
%setup -q

%build
%configure  --disable-static
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
rm %{buildroot}%{_libdir}/*.la

%post   -n lib%{name}-%{soname} -p /sbin/ldconfig
%postun -n lib%{name}-%{soname} -p /sbin/ldconfig

%files -n lib%{name}-%{soname} 
%defattr(-,root,root)
%{_libdir}/lib*.so.*

%files devel
%defattr(-,root,root)
%{_includedir}/log4cplus/
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/log4cplus.pc

%changelog
* Mon Mar  4 2013 jengelh@inai.de
- Kill off %%make_install to unbreak SLE build
* Fri Oct  5 2012 toddrme2178@gmail.com
- Update to 1.1.0
  - Fixed MacOS X support - Reimplemented semaphores using named ones
    for Apple builds
  - Fixed resource leak on failure in openSocket()
  - Improved configuration file modification check to include file
    size, in addition to file modification time
  - Fixed non-STLPort4 builds with Solaris Studio. Switch
    '-library=stlport4' is only added if CXXFLAGS does not already
    contain a switch matching -library=(stlport4|stdcxx4|Cstd)
  - Fixed --disable-shared MinGW builds
  - Fixed non-working MinGW DLL binaries. DllMain() was not being
    called because of missing extern "C" in its definition
  - CMake build configuration checks have been improved
  - GCC switch -O2 is only added if CXXFLAGS does not already contain
    any other -O
  - Improved logging speed using SysLogAppender and Log4jUdpAppender
    by optimizations in both the loggers and in common sockets code
  - FileAppender locale can now be specified in properties files using
    Locale property. See FileAppender Doxygen documentation for more
    details
  - Improved Log4jUdpAppender compatibility with Chainsaw
  - Fixed crash, bugs #3467112 and #3563699, related to thread-local
    storage destruction
  - Fixed build with Visual Studio 2005, bug #3565529
  - Created Cygwin port's .cygport definition for log4cplus
  - Improved hiding of private symbols using GCC's
    __attribute__((visibility("hidden"))) and Solaris Studio's
    __hidden
  - Fixed build in environments where DEBUG (and other log level
    names) are macros.
  - Improved configuration of threads support
  - Turned on __thread (TLS) detection on NetBSD 5.1.0 and later that
    has been previously disabled
  - Improved compatibility with log4cplus 1.0.x: allow using log4cplus
    1.0.x log level to string callbacks in 1.1.x
  - Improved various M4 macros
  - Added detection and use C++11 thread_local
  - Fixed XML entities escaping in Log4jUdpAppender
  - Re-added synchronization between ConsoleAppender and LogLog
  - Changed C logger API to return int instead of bool
  - Added C logger API to Visual Studio 2010 projects
  - Implemented remote syslog logging using UDP in SysLogAppender
  - Enabled SysLogAppender on Windows with only remote syslog logging
    enabled
  - IMPORTANT: Builds with --with-iconv configure switch now assume
    UTF-8 for plain char strings
  - Bumped up SO version for UDP sockets support related changes
  - Removed Windows CE support
  - Regenerated with Automake 1.12.2
  - Fixed Fedora RPM builds spec file
  - Implemented log4cplus.disableOverride similar to log4j's
    log4j.disableOverride
  - Improved support of profiling and debugging builds with Sun CC
  - Added documentation for configure script options
  - Added detection and use of clock_nanosleep()
  - Disabled __thread (TLS) detection for NetBSD. It is broken there
  - New appender: Log4jUdpAppender. It allows logging using UDP with
    log4j XML payload to Chainsaw or Log2Console
  - Added support for __func__ as function name source for logging
    events
  - Fixed compilation for build with wchar_t being alias to unsigned
    short (/Zc:wchar_t-) (Windows)
  - Added new appender CLFSAppender (experimental), based on Microsoft
    Common Log File System API
  - Added new appender Qt4DebugAppender (experimenta), based on Qt4's
    qDebug(), qWarning() and qCritical() functions
  - Fixed bug #3530769 - compilation issues with Visual Studio 2011
  - Added log4cplus.quietMode property handling to
    PropertyConfigurator
  - Added #pragma once to all headers
  - Implemented Time::gettimeofday() using Win32 API's
    GetSystemTimeAsFileTime()
  - Moved file based locking from FileAppender to Appender to make it
    available for all appenders
  - Changed Windows configuration to use __declspec(thread) when
    compiling for Windows Vista or later and TlsAlloc() otherwise
  - Implemented %%r PatternLayout format specifier - miliseconds since
    process start
  - Fixed bug #3101459 - TTCCLayout time is not in milliseconds since
    process start by default
  - Fixed single threaded log4cplus build issues
  - Added ability to log to std::cerr
  - Fixed disabling of LOG4CPLUS_*_FMT() macros
  - IMPORTANT: Compilation with Solaris Studio now depends on STLPort
    (-library=stlport4 switch). The default Cstd library is not
    conforming enough for use in log4cplus
  - Improved behaviour of log4cplus as a component of larger CMake
    based project
  - Updated various Autoconf detection scripts in m4/ directory to
    newer versions
  - Fixed some signedness and overflow warnings
  - Improved Autotools build system's behaviour for cross compilation
  - Added detection of C++11 <atomic> header and related functions.
    Implemented SharedObject reference counting using C++11 atomics
    where possible
  - Fixed compilation with GCC 4.6 in C++11 mode
  - Fixed some single-threaded compilation and run time issues
  - Fixed bug #3520891 - FileAppender buffering issue
  - Updated to Autoconf 2.69, Automake 1.12 and Libtool 2.4.2
  - Documented build procedure for Solaris Studio
  - Improved support for Solaris Studio in configure.in
  - Fixed log4cplusS.vcxproj - Added missing source files to the
    project
  - CMake build system fixes
  - Fixed TTCCLayout double time stamp issue
  - Important changes relative to PRODUCTION_1_0_x branch:
  - Added AsyncAppender
  - Added simple C interface for interoperability with C
  - Added inter-process file locking to file appenders to allow
    logging into a single log file from multiple processes
  - Added Mapped Diagnostic Context (MDC) and associated converter
    (%%X)
  - Added alternative thread identification (%%T) converter to pattern
    layout
  - Added function name converter (%%M)
  - Added wchar_t <-> char conversion implementations based on
    standard C locale functions and based on iconv()
  - Added DeviceAppender to allow use of Boost.IOStream's Sink as
    appender
  - Added LOG4CPLUS_*_FMT() macros to allow printf-like formatted
    output where it is possible
  - Logging macros now accept both logger name as string and Logger
    instance as their first parameter
- Update sonum 1.1-5
* Wed Jun  6 2012 cfarrell@suse.com
- license update: Apache-2.0
  SPDX format
* Fri Sep 23 2011 toddrme2178@gmail.com
- Renamed to log4cplus to match upstream name
- Update to 1.0.4 - bugfix release
- Update to 1.0.3 - bugfix release
- Update to 1.0.2 - bugfix release
- Update to 1.0.1 - bugfix release
- Cleaned up spec file formatting
* Wed Jan 14 2009 bbrunner@suse.de
- initial package
